game_qu.math API documentation
Description: This module has all the game engine math classes (functions, derivatives, vectors, etc.)

# Module `game_qu.math`

This module has all the game engine math classes (functions, derivatives, vectors, etc.)

Expand source code

    """This module has all the game engine math classes (functions, derivatives, vectors, etc.)"""

## Sub-modules

`game_qu.math.bounded_function`
`game_qu.math.derivative`
`game_qu.math.function`
`game_qu.math.indefinite_integral`
`game_qu.math.line_segment`
`game_qu.math.linear_interpolation`
`game_qu.math.matrix`
`game_qu.math.physics_function`
`game_qu.math.piecewise_function`
`game_qu.math.point`
`game_qu.math.polynomial`
`game_qu.math.quadratic_function`
`game_qu.math.range`
`game_qu.math.vector_2d`